==> fluxbox_1.3.5.orig.tar.gz: fluxbox-1.3.5/nls/zh_CN/generated-GBK.m <==
$ codeset=GBK

$set 1 #Align

1 ·
2 ·
3 ·
4 ˮƽ
5 
6 ·
7 
8 Ϸ
9 չ
10 
11 ·
12 Ҳ
13 Ϸ
14 Ϸ
15 Ϸ
16 Ϸ
17 ֱ

$set 2 #BaseDisplay

1 ˳... 洢ļ\n
2 ر\n
3 %s:      ź %d\n

$set 3 #Common

1 Alphaֵ
2 Զ
3 ʱ
4 ѡ
5 
6 汾
7 	ʼ
8 	
9 	֧
10 	˵
11 	ʽ
12 Ĭ
13 
14 
15 Fluxbox汾
16 ʱǹ
17 GIT޶汾
18 ɼ
19 δκα\nοֲĶFAQ

$set 4 #Configmenu

1 
2 Զ
3 
4 ۽
5 װʱ
6 л
7 Focus Window on Workspace Change
8 ۽ģʽ
9 ۽´
10 ȫ
11 ͼɫ
12 ƶʱʾ
14 ۽
15 
16 ǿα͸
17 ˵Alphaֵ
18 ͸
19 ۽Alphaֵ
20 Ǿ۽Alphaֵ
21 ǩѡ
22 ǩڱ
23 ñǩ
24 ۽ǩ
25 ۽ǩ

$set 5 #Ewmh

1 : ڴ治,޷ΪEWMH client listڴ

$set 6 #FbTkError

1 棡 Height > 3200  Height = 3200
2 棡 Width > 3200  Width = 3200
3 : ܼر
4 
5 ӳ
6 ޷XImage
7 ȡʧ
8 棺޷ΪalphaҵЧʽ
9 棺alphaͼƬʧܡ
10 棺alphaӳʧܡ
11 Ļʽʧ(%d)
12 ڴ治
13 ڴ治㣬޷blue buffer
14 ڴ治㣬޷green buffer
15 ڴ治㣬޷red buffer
16 ȡĿʧ
17 ֧ͼģʽ
18 Ĭֵ

$set 7 #Fluxbox

1 Чrcļ!
2 ļʧ
3 ݿʧ
4 Retrying with
5 棡޷ҵĻƴڣ
6 ޷ %s Ŀ¼
7 ޷ҵҪƵĻ\nȷûڹС
8 ﷨
9 fluxboxֻһʵ
10 ޷X server\nȷ㿪Fluxbox֮ǰX
11 棺X server֧locale
12 棺޷locale modifiers

$set 8 #Gnome

1 : ڴ治, ޷ΪGNOME client listڴ

$set 9 #Keys

1 Keys: Error on line
2 Keys: Failed to merge keytree!
3 Keys: Invalid key/modifier on line

$set 10 #Menu

1 
2 FluxboxĬϲ˵
3 ˳
4 ͼ
5 ...
6 λڼ...
7 λ
8 ¼ļ
9 Fluxbox
10 棺[encoding]ǩԳ

$set 11 #Remember

1 װ
2 ߴ
3 
4 
5 ס...
6 λ
7 رʱ
8 
9 ճס
10 δ֪
11 
12 

$set 12 #Screen

1 BScreen::BScreen: ѯX serverʱ.\n һڹ,displayΪ
2 W: %4d x H: %4d
3 BScreen::BScreen: Ļ %d ʹͼģʽ 0x%lx, ɫ %d\n
4 W: %04d x H: %04d

$set 13 #Slit

1 Clients
2 ¾
3 Ͼ
4 Slit
5 Slit
6 Slitλڼ
7 Slitλ
8 Slit
9 Slitб

$set 14 #Toolbar

1 ǰ
2 ͼģʽ
3 д
4 СĴ
5 
6 ǰд
7 ǰСĴ
8 
9 λڼ
10 λ
11 
12 Ȱٷֱ
13 ʱӣ24Сʱʽ
14 ʱӣ12Сʱʽ
15 ༭ʱʾʽ
16 ʾͼ
17 δСĴ
18 ǰδСĴ

$set 15 #Window

1 δ

$set 16 #Windowmenu

1 ر
2 С
3 
4 
5 
6 
7 ͵...
8 
9 ճס
10 ɱ

$set 17 #Workspace

1  %d
2 
3 ½
4 Ƴһ

$set 18 #fbsetroot

1 : ָ: -solid, -mod, -gradient еһ.\n
2 ޷pixmap atoms
3 -display <string>        display connection\n\
-mod <x> <y>             modula pattern\n\
-foreground, -fg <color> modula foreground color\n\
-background, -bg <color> modula background color\n\n\
-gradient <texture>      gradient texture\n\
-from <color>            gradient start color\n\
-to <color>              gradient end color\n\n\
-solid <color>           solid color\n\n\
-help                    ʾϢ\n

$set 19 #main

1 : '-display'Ҫһ
2 Bad Alloc
3 Bad cast
4 ʾΧ
5 ʱ
6 ׼
7 δ֪
8 : '-log'Ҫһ
9 ־ļ
10 ¼־
11 : '-rc'Ҫһ
12 : '-screen'Ҫһ
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\
ҳ: http://www.fluxbox.org/\n\n\
-display <string>\t\tָdisplayӡ\n\
-screen <all|int,int,int>\tضĻʾ\n\
-rc <string>\t\t\tʹָԴļ\n\
-version\t\t\tʾ汾Ȼ˳\n\
-info\t\t\t\tʾһЩõϢ\n\
-log <filename>\t\t\t¼ļС\n\
-help\t\t\t\tʾϢȻ˳\n\n
14 : ޷û'DISPLAY'

$set 20

1 Dock֮
2 ײ
3 
4 Dock
5 ͨ
6

==> fluxbox_1.3.7.orig.tar.gz: fluxbox-1.3.7/nls/zh_CN/generated-GBK.m <==
$ codeset=GBK

$set 1 #Align

1 ·
2 ·
3 ·
4 ˮƽ
5 
6 ·
7 
8 Ϸ
9 չ
10 
11 ·
12 Ҳ
13 Ϸ
14 Ϸ
15 Ϸ
16 Ϸ
17 ֱ

$set 2 #BaseDisplay

1 ˳... 洢ļ\n
2 ر\n
3 %s:      ź %d\n

$set 3 #Common

1 Alphaֵ
2 Զ
3 ʱ
4 ѡ
5 
6 汾
7 	ʼ
8 	
9 	֧
10 	˵
11 	ʽ
12 Ĭ
13 
14 
15 Fluxbox汾
16 ʱǹ
17 GIT޶汾
18 ɼ
19 δκα\nοֲĶFAQ

$set 4 #Configmenu

1 
2 Զ
3 
4 ۽
5 װʱ
6 л
7 Focus Window on Workspace Change
8 ۽ģʽ
9 ۽´
10 ȫ
11 ͼɫ
12 ƶʱʾ
14 ۽
15 
16 ǿα͸
17 ˵Alphaֵ
18 ͸
19 ۽Alphaֵ
20 Ǿ۽Alphaֵ
21 ǩѡ
22 ǩڱ
23 ñǩ
24 ۽ǩ
25 ۽ǩ

$set 5 #Ewmh

1 : ڴ治,޷ΪEWMH client listڴ

$set 6 #FbTkError

1 棡 Height > 3200  Height = 3200
2 棡 Width > 3200  Width = 3200
3 : ܼر
4 
5 ӳ
6 ޷XImage
7 ȡʧ
8 棺޷ΪalphaҵЧʽ
9 棺alphaͼƬʧܡ
10 棺alphaӳʧܡ
11 Ļʽʧ(%d)
12 ڴ治
13 ڴ治㣬޷blue buffer
14 ڴ治㣬޷green buffer
15 ڴ治㣬޷red buffer
16 ȡĿʧ
17 ֧ͼģʽ
18 Ĭֵ

$set 7 #Fluxbox

1 Чrcļ!
2 ļʧ
3 ݿʧ
4 Retrying with
5 棡޷ҵĻƴڣ
6 ޷ %s Ŀ¼
7 ޷ҵҪƵĻ\nȷûڹС
8 ﷨
9 fluxboxֻһʵ
10 ޷X server\nȷ㿪Fluxbox֮ǰX
11 棺X server֧locale
12 棺޷locale modifiers

$set 8 #Gnome

1 : ڴ治, ޷ΪGNOME client listڴ

$set 9 #Keys

1 Keys: Error on line
2 Keys: Failed to merge keytree!
3 Keys: Invalid key/modifier on line

$set 10 #Menu

1 
2 FluxboxĬϲ˵
3 ˳
4 ͼ
5 ...
6 λڼ...
7 λ
8 ¼ļ
9 Fluxbox
10 棺[encoding]ǩԳ

$set 11 #Remember

1 װ
2 ߴ
3 
4 
5 ס...
6 λ
7 رʱ
8 
9 ճס
10 δ֪
11 
12 

$set 12 #Screen

1 BScreen::BScreen: ѯX serverʱ.\n һڹ,displayΪ
2 W: %4d x H: %4d
3 BScreen::BScreen: Ļ %d ʹͼģʽ 0x%lx, ɫ %d\n
4 W: %04d x H: %04d

$set 13 #Slit

1 Clients
2 ¾
3 Ͼ
4 Slit
5 Slit
6 Slitλڼ
7 Slitλ
8 Slit
9 Slitб

$set 14 #Toolbar

1 ǰ
2 ͼģʽ
3 д
4 СĴ
5 
6 ǰд
7 ǰСĴ
8 
9 λڼ
10 λ
11 
12 Ȱٷֱ
13 ʱӣ24Сʱʽ
14 ʱӣ12Сʱʽ
15 ༭ʱʾʽ
16 ʾͼ
17 δСĴ
18 ǰδСĴ

$set 15 #Window

1 δ

$set 16 #Windowmenu

1 ر
2 С
3 
4 
5 
6 
7 ͵...
8 
9 ճס
10 ɱ

$set 17 #Workspace

1  %d
2 
3 ½
4 Ƴһ

$set 18 #fbsetroot

1 : ָ: -solid, -mod, -gradient еһ.\n
2 ޷pixmap atoms
3 -display <string>        display connection\n\
-mod <x> <y>             modula pattern\n\
-foreground, -fg <color> modula foreground color\n\
-background, -bg <color> modula background color\n\n\
-gradient <texture>      gradient texture\n\
-from <color>            gradient start color\n\
-to <color>              gradient end color\n\n\
-solid <color>           solid color\n\n\
-help                    ʾϢ\n

$set 19 #main

1 : '-display'Ҫһ
2 Bad Alloc
3 Bad cast
4 ʾΧ
5 ʱ
6 ׼
7 δ֪
8 : '-log'Ҫһ
9 ־ļ
10 ¼־
11 : '-rc'Ҫһ
12 : '-screen'Ҫһ
13 Fluxbox %s: (c) %s Fluxbox Team\n\
ҳ: http://www.fluxbox.org/\n\n\
-display <string>\t\tָdisplayӡ\n\
-screen <all|int,int,int>\tضĻʾ\n\
-no-slit\t\t\tdo not provide a slit.\n\
-no-toolbar\t\t\tdo not provide a toolbar.\n\
-rc <string>\t\t\tʹָԴļ\n\
-version\t\t\tʾ汾Ȼ˳\n\
-info\t\t\t\tʾһЩõϢ\n\
-list-commands\t\t\tlist all valid key commands.\n\
-sync\t\t\t\tsynchronize with X server for debugging.\n\
-log <filename>\t\t\t¼ļС\n\
-help\t\t\t\tʾϢȻ˳\n\n
14 : ޷û'DISPLAY'

$set 20

1 Dock֮
2 ײ
3 
4 Dock
5 ͨ
6
